Struct
TemplateScope
Instance methods
tmpl_scope_new_with_parent
Creates a new scope to contain variables and custom expressions,
If parent is set, the parent scope will be inherited.
Creates a new scope to contain variables and custom expressions,
If parent is set, the parent scope will be inherited.